summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoQueryTrader.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoQueryTrader.cpp')
-rw-r--r--lib/kofficecore/KoQueryTrader.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kofficecore/KoQueryTrader.cpp b/lib/kofficecore/KoQueryTrader.cpp
index 54699ca1..9c4620d1 100644
--- a/lib/kofficecore/KoQueryTrader.cpp
+++ b/lib/kofficecore/KoQueryTrader.cpp
@@ -31,7 +31,7 @@
#include <limits.h> // UINT_MAX
/**
* Port from KOffice Trader to KTrader/KActivator (kded) by Simon Hausmann
* (c) 1999 Simon Hausmann <hausmann@kde.org>
* Port to KService and simplifications by David Faure <faure@kde.org>
*/
@@ -123,9 +123,9 @@ TQValueList<KoDocumentEntry> KoDocumentEntry::query( bool _onlyDocEmb, const TQS
constr += " exist Library";
// Query the trader
- KTrader::OfferList offers = KTrader::self()->query( "KOfficePart", constr );
+ TDETrader::OfferList offers = TDETrader::self()->query( "KOfficePart", constr );
- KTrader::OfferList::ConstIterator it = offers.begin();
+ TDETrader::OfferList::ConstIterator it = offers.begin();
unsigned int max = offers.count();
for( unsigned int i = 0; i < max; i++, ++it )
{
@@ -174,9 +174,9 @@ TQValueList<KoFilterEntry::Ptr> KoFilterEntry::query( const TQString & _constr )
kdDebug(30500) << "KoFilterEntry::query( " << _constr << " )" << endl;
TQValueList<KoFilterEntry::Ptr> lst;
- KTrader::OfferList offers = KTrader::self()->query( "KOfficeFilter", _constr );
+ TDETrader::OfferList offers = TDETrader::self()->query( "KOfficeFilter", _constr );
- KTrader::OfferList::ConstIterator it = offers.begin();
+ TDETrader::OfferList::ConstIterator it = offers.begin();
unsigned int max = offers.count();
//kdDebug(30500) << "Query returned " << max << " offers" << endl;
for( unsigned int i = 0; i < max; i++ )
@@ -31,7 +31,7 @@
#include <limits.h> // UINT_MAX
/**
- * Port from KOffice Trader to KTrader/KActivator (kded) by Simon Hausmann
+ * Port from KOffice Trader to TDETrader/KActivator (kded) by Simon Hausmann
* (c) 1999 Simon Hausmann <hausmann@kde.org>
* Port to KService and simplifications by David Faure <faure@kde.org>